@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.c,v 1.67 2007/05/11 00:42:16 bowkenken Exp $
+* $Id: amenu.c,v 1.71 2008/01/11 09:12:57 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -658,7 +658,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 {
 	long	left_max_len;
 	menu_t	*p;
-	char	buf[MSG_TTL_AUTO_MARK_MAX_LEN * 2 + 16 + 1];
+	char	buf[MSG_TTL_AUTO_MARK_MAX_LEN * 3 + 16 + 1];
 	char	key;
 	long	i, k;
 
@@ -694,6 +694,8 @@ void	set_menu_auto_mark( menu_t **dflt )
 		len = str_len_draw( get_msg_ttl_auto_mark_info( i ) );
 		left_max_len = max_l( left_max_len, len );
 	}
+	if( left_max_len > MSG_TTL_AUTO_MARK_INFO_MAX_LEN )
+		left_max_len = MSG_TTL_AUTO_MARK_INFO_MAX_LEN;
 
 	for( i = 0; i < AUTO_MARK_MAX_N; i++ ){
 		long	kk;
@@ -1375,7 +1377,7 @@ char	*cb_menu_auto_mark_edit_init(
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_EDIT,
-			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
 	/* о */
@@ -1453,7 +1455,7 @@ char	*cb_menu_auto_mark_trgt_init(
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_TRGT,
-			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
 	s = NULL;
@@ -1556,7 +1558,7 @@ char	*cb_menu_auto_mark_dist_init(
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_DIST,
-			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
 	s = NULL;
@@ -1619,7 +1621,7 @@ char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt )
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_ACT,
-			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
 	s = NULL;
@@ -1769,7 +1771,7 @@ char	*cb_menu_auto_mark_cond_init(
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_COND,
-			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
 	/* ǥեȤΥ */
@@ -1846,7 +1848,7 @@ char	*cb_menu_auto_mark_cond_init(
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_COND,
-			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
 	return NULL;
@@ -1912,7 +1914,7 @@ char	*cb_menu_auto_mark_appoint_item(
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	sprintf( ls[k].msg, MSG_TTL_MENU_AUTO_MARK_APPOINT_ITEM_MJR,
-			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
@@ -2302,15 +2304,15 @@ char	*cb_menu_auto_mark_paste_small( menu_t **pp, menu_t **dflt )
 char	*cb_menu_auto_mark_edit_name( menu_t **pp, menu_t **dflt )
 {
 	long	n;
-	static char	info[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
-	static char	hint[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+	static char	info[MSG_TTL_AUTO_MARK_INFO_MAX_LEN + 1];
+	static char	hint[MSG_TTL_AUTO_MARK_HINT_MAX_LEN + 1];
 
 	n = (long)((*pp)->arg);
 
 	str_nz_cpy( info, get_msg_ttl_auto_mark_info( n ),
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_INFO_MAX_LEN );
 	str_nz_cpy( hint, get_msg_ttl_auto_mark_hint( n ),
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_HINT_MAX_LEN );
 
 	wipe_all();
 	gets_auto_mark_info( info );
@@ -2375,6 +2377,29 @@ char	*cb_menu_auto_mark_arrange_bottom( menu_t **pp, menu_t **dflt )
 ***************************************************************/
 
 char	*menu_auto_mark_arrange( long n, long d )
+{
+	if( !arrange_auto_mark( n, d ) )
+		return STR_MENU_ERR;
+
+	if( d <= -1 ){
+		print_msg( FLG_NULL,
+				MSG_MENU_AUTO_MARK_DONE_ARRANGE_TOP );
+	} else {
+		print_msg( FLG_NULL,
+				MSG_MENU_AUTO_MARK_DONE_ARRANGE_BOTTOM );
+	}
+
+	return "/auto mark";
+}
+
+/***************************************************************
+* ˥塼¤ٴ
+* long n : ϰ
+* long d : Ƭ(-1)/(+1)
+* return : ?
+***************************************************************/
+
+bool_t	arrange_auto_mark( long n, long d )
 {
 	long	i, j, k;
 	auto_mark_t	am;
@@ -2388,7 +2413,7 @@ char	*menu_auto_mark_arrange( long n, long d )
 	else if( d >= +1 )
 		d = +1;
 	else
-		return STR_MENU_ERR;
+		return FALSE;
 
 	for( i = 0; i < LS_MBR_MAX_N; i++ ){
 		am = ls_auto_mark[i][n];
@@ -2469,15 +2494,96 @@ char	*menu_auto_mark_arrange( long n, long d )
 
 	auto_mark_cur_n = 0;
 
-	if( d <= -1 ){
-		print_msg( FLG_NULL,
-				MSG_MENU_AUTO_MARK_DONE_ARRANGE_TOP );
-	} else {
-		print_msg( FLG_NULL,
-				MSG_MENU_AUTO_MARK_DONE_ARRANGE_BOTTOM );
+	return TRUE;
+}
+
+/***************************************************************
+* ˥塼¤ٴ(Сñ)
+* long ls_mbr_n : С
+* long d : Ƭ(-1)/(+1)
+* return : ?
+***************************************************************/
+
+bool_t	arrange_auto_mark_mbr( long ls_mbr_n, long d )
+{
+	long	i, j, k;
+	auto_mark_t	am[AUTO_MARK_MAX_N];
+	auto_mark_appoint_item_t	item
+			[AUTO_MARK_MAX_N]
+			[AUTO_MARK_APPOINT_ITEM_MAX_N];
+	auto_mark_appoint_item_t	item_tmp;
+	const long	max_item = AUTO_MARK_APPOINT_ITEM_MAX_N;
+	mbr_t	**ls_mbr = get_ls_mbr();
+
+	if( d <= -1 )
+		d = -1;
+	else if( d >= +1 )
+		d = +1;
+	else
+		return FALSE;
+
+	ls_mbr = get_ls_mbr();
+
+	for( j = 0; j < AUTO_MARK_MAX_N; j++ ){
+		am[j] = ls_auto_mark[ls_mbr_n][j];
+
+		for( k = 0; k < max_item; k++ ){
+			item[j][k] = auto_mark_appoint_item[ls_mbr_n][j][k];
+		}
 	}
 
-	return "/auto mark";
+	if( d <= -1 ){
+		for( i = ls_mbr_n; i > 0; i-- ){
+			for( j = 0; j < AUTO_MARK_MAX_N; j++ ){
+				ls_auto_mark[i][j] = ls_auto_mark[i - 1][j];
+
+				for( k = 0; k < max_item; k++ ){
+					item_tmp = auto_mark_appoint_item
+							[i - 1][j][k];
+					auto_mark_appoint_item[i][j][k]
+							= item_tmp;
+				}
+			}
+		}
+	} else {
+		for( i = ls_mbr_n; i < LS_MBR_MAX_N - 1; i++ ){
+			if( chk_flg( ls_mbr[i + 1]->stat,
+					FLG_STAT_NOT_EXIST ) ){
+				break;
+			}
+			for( j = 0; j < AUTO_MARK_MAX_N; j++ ){
+				ls_auto_mark[i][j] = ls_auto_mark[i + 1][j];
+
+				for( k = 0; k < max_item; k++ ){
+					item_tmp = auto_mark_appoint_item
+							[i + 1][j][k];
+					auto_mark_appoint_item[i][j][k]
+							= item_tmp;
+				}
+			}
+		}
+	}
+
+	for( j = 0; j < AUTO_MARK_MAX_N; j++ ){
+		ls_auto_mark[i][j] = am[j];
+
+		for( k = 0; k < max_item; k++ ){
+			auto_mark_appoint_item[i][j][k] = item[j][k];
+		}
+	}
+
+	return TRUE;
+}
+
+/***************************************************************
+* ˥塼κ(Сñ)
+* long ls_mbr_n : С
+* return : ?
+***************************************************************/
+
+bool_t	remove_auto_mark_mbr( long ls_mbr_n )
+{
+	return arrange_auto_mark_mbr( ls_mbr_n, +1 );
 }
 
 /***************************************************************
@@ -2687,22 +2793,22 @@ char	*get_msg_ttl_auto_mark_name( long n )
 
 char	*get_msg_ttl_auto_mark_info( long n )
 {
-	static char	str[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+	static char	str[MSG_TTL_AUTO_MARK_INFO_MAX_LEN + 1];
 	char	*ttl, *p;
 
 	ttl = msg_ttl_auto_mark[n];
 
 	p = strstr( ttl, STR_TTL_AUTO_MARK_SPLIT_CODE );
 	if( p == NULL ){
-		str_nz_cpy( str, ttl, MSG_TTL_AUTO_MARK_MAX_LEN );
+		str_nz_cpy( str, ttl, MSG_TTL_AUTO_MARK_INFO_MAX_LEN );
 	} else {
 		long	len;
 
 		len = p - ttl;
 		if( len < 0 )
 			len = 0;
-		if( len > MSG_TTL_AUTO_MARK_MAX_LEN )
-			len = MSG_TTL_AUTO_MARK_MAX_LEN;
+		if( len > MSG_TTL_AUTO_MARK_INFO_MAX_LEN )
+			len = MSG_TTL_AUTO_MARK_INFO_MAX_LEN;
 
 		str_nz_cpy( str, ttl, len );
 	}
@@ -2718,7 +2824,7 @@ char	*get_msg_ttl_auto_mark_info( long n )
 
 char	*get_msg_ttl_auto_mark_hint( long n )
 {
-	static char	str[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+	static char	str[MSG_TTL_AUTO_MARK_HINT_MAX_LEN + 1];
 	char	*ttl, *p;
 
 	ttl = msg_ttl_auto_mark[n];
@@ -2730,7 +2836,7 @@ char	*get_msg_ttl_auto_mark_hint( long n )
 		long	len;
 
 		len = str_len_std( STR_TTL_AUTO_MARK_SPLIT_CODE );
-		str_nz_cpy( str, &(p[len]), MSG_TTL_AUTO_MARK_MAX_LEN );
+		str_nz_cpy( str, &(p[len]), MSG_TTL_AUTO_MARK_HINT_MAX_LEN );
 	}
 
 	return str;
