@@ -143,6 +143,7 @@ long	get_lev( chr_t *chr, abl_kind_t abl );
 long	get_lev_max( chr_t *chr, abl_kind_t abl );
 rate_t	get_resi( chr_t *chr, resi_kind_t resi );
 bool_t	chk_modified_lev( chr_t *chr, abl_kind_t abl );
+long	calc_abl_to_val( chr_t *chr, abl_kind_t abl );
 long	calc_lev_to_val( long lev, abl_kind_t abl );
 long	calc_max_hp( chr_t *chr );
 long	calc_max_mp( chr_t *chr );
@@ -165,11 +166,16 @@ void	set_square( chr_t *chr, square_t *sq );
 char	*get_trgt_name( trgt_t *trgt );
 trgt_kind_t	get_trgt_kind_from_chr( chr_t *chr );
 chr_kind_t	get_chr_kind_from_trgt( trgt_t *trgt );
+void	copy_chr( chr_t *dst, chr_t *src );
 bool_t	cmp_chr( chr_t *p1, chr_t *p2 );
 rate_t	calc_rate_equip(
 	chr_t *chr, abl_kind_t abl_main, abl_kind_t abl_sub
 );
 bool_t	chk_find_chr( chr_t *p1, chr_t *p2 );
+bool_t	is_mbr( chr_t *p );
+bool_t	is_mnstr( chr_t *p );
+bool_t	is_mnstr_or_pet( chr_t *p );
+bool_t	is_pet( chr_t *p );
 void	set_chr_id( chr_t *chr, chr_t **ls, long max );
 long	calc_chr_id1( char *name );
 long	calc_chr_id2( char *name );
