@@ -39,6 +39,10 @@ int	curs_getch( void );
 void	curs_getnstr( char *s, int len );
 bool_t	chk_color( void );
 long	get_max_line( void );
+bool_t	chk_flg_screen_size_auto( void );
+void	set_flg_screen_size_auto( bool_t flg );
+long	get_screen_size_lines( void );
+void	set_screen_size_lines( long n );
 int	attr_dos( curs_attr_t *attr );
 
 #ifdef __cplusplus
