@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: curs.c,v 1.72 2007/11/09 06:49:38 bowkenken Exp $
+* $Id: curs.c,v 1.74 2008/04/03 08:17:01 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -39,6 +39,9 @@
 * ѿ
 ***************************************************************/
 
+static bool_t	g_flg_screen_size_auto;
+static long	g_screen_size_lines;
+
 /* ס󥹤Ȥäȿž°褹뤫? */
 #define	FLG_PRINT_REVERSE	0
 
@@ -128,6 +131,9 @@ static curs_attr_t	g_curs_attr[CURS_ATTR_MAX_N] = {
 
 void	init_curs( void )
 {
+	set_flg_screen_size_auto( TRUE );
+	set_screen_size_lines( 24 );
+
 	flg_curs = 0;
 	flg_curs_draw = 0;
 	curs_attrset_dflt();
@@ -877,6 +883,9 @@ long	get_max_line( void )
 	if( !g_flg_cui )
 		return 1;
 
+	if( !chk_flg_screen_size_auto() )
+		return get_screen_size_lines();
+
 #if	HAVE_LIBCURSES
 	if( chk_curs() ){
 		return LINES;
@@ -897,6 +906,54 @@ long	get_max_line( void )
 	return SCREEN_HEIGHT;
 }
 
+/***************************************************************
+* ̥μư꤬ͭĴ٤
+* return : ͭ?
+***************************************************************/
+
+bool_t	chk_flg_screen_size_auto( void )
+{
+	return g_flg_screen_size_auto;
+}
+
+/***************************************************************
+* ̥μư̵ͭˤ
+* bool_t flg : ̵ͭ
+***************************************************************/
+
+void	set_flg_screen_size_auto( bool_t flg )
+{
+	if( flg )
+		g_flg_screen_size_auto = TRUE;
+	else
+		g_flg_screen_size_auto = FALSE;
+}
+
+/***************************************************************
+* ̤κԿ֤ͤ
+* return : Կ
+***************************************************************/
+
+long	get_screen_size_lines( void )
+{
+	return g_screen_size_lines;
+}
+
+/***************************************************************
+* ̤κԿ
+* return : Կ
+***************************************************************/
+
+void	set_screen_size_lines( long n )
+{
+	if( n < SCREEN_SIZE_MIN_LINES )
+		n = SCREEN_SIZE_MIN_LINES;
+	if( n > SCREEN_SIZE_MAX_LINES )
+		n = SCREEN_SIZE_MAX_LINES;
+
+	g_screen_size_lines = n;
+}
+
 /***************************************************************
 * DOS ѤοѴ
 * curs_attr_t *attr : ⡼
