@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: curs.h,v 1.32 2007/01/11 17:31:34 bowkenken Exp $
+* $Id: curs.h,v 1.34 2008/04/03 08:17:01 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CURS_H
@@ -102,4 +102,11 @@ typedef struct {
 	chtype_t	attr;
 } curs_attr_t;
 
+/***************************************************************
+* ̥
+***************************************************************/
+
+#define	SCREEN_SIZE_MIN_LINES	22
+#define	SCREEN_SIZE_MAX_LINES	128
+
 #endif	/* CURS_H */
