@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: draw.h,v 1.55 2007/03/11 20:49:58 bowkenken Exp $
+* $Id: draw.h,v 1.57 2008/01/11 09:12:57 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DRAW_H
@@ -83,13 +83,17 @@
 #define	WIN_MAP_DRAW_MIN_Y	0
 #define	WIN_MAP_DRAW_WIDTH	(WIN_MAP_WIDTH * 2)
 #define	WIN_MAP_DRAW_HEIGHT	WIN_MAP_HEIGHT
-#define	WIN_MAP_DRAW_MAX_X	(WIN_MAP_DRAW_MIN_X + WIN_MAP_DRAW_WIDTH - 1)
-#define	WIN_MAP_DRAW_MAX_Y	(WIN_MAP_DRAW_MIN_Y + WIN_MAP_DRAW_HEIGHT - 1)
+#define	WIN_MAP_DRAW_MAX_X	\
+		(WIN_MAP_DRAW_MIN_X + WIN_MAP_DRAW_WIDTH - 1)
+#define	WIN_MAP_DRAW_MAX_Y	\
+		(WIN_MAP_DRAW_MIN_Y + WIN_MAP_DRAW_HEIGHT - 1)
 
 #define	WIN_MENU_DRAW_MIN_X	SCREEN_MIN_X
 #define	WIN_MENU_DRAW_MIN_Y	SCREEN_MIN_Y
-#define	WIN_MENU_DRAW_WIDTH	(WIN_MENU_DRAW_MAX_X - WIN_MENU_DRAW_MIN_X)
-#define	WIN_MENU_DRAW_HEIGHT	(WIN_MENU_DRAW_MAX_Y - WIN_MENU_DRAW_MIN_Y)
+#define	WIN_MENU_DRAW_WIDTH	\
+		(WIN_MENU_DRAW_MAX_X - WIN_MENU_DRAW_MIN_X + 1)
+#define	WIN_MENU_DRAW_HEIGHT	\
+		(WIN_MENU_DRAW_MAX_Y - WIN_MENU_DRAW_MIN_Y + 1)
 #define	WIN_MENU_DRAW_MAX_X	SCREEN_MAX_X
 #define	WIN_MENU_DRAW_MAX_Y	(WIN_MSG_DRAW_MIN_Y - 1)
 
@@ -97,10 +101,13 @@
 #define	WIN_MSG_DRAW_MIN_Y	(WIN_MAP_DRAW_MAX_Y + 2)
 #define	WIN_MSG_DRAW_WIDTH	(SCREEN_WIDTH - 1)
 #define	WIN_MSG_DRAW_HEIGHT	1
-#define	WIN_MSG_DRAW_MAX_X	(WIN_MSG_DRAW_MIN_X + WIN_MSG_DRAW_WIDTH - 1)
-#define	WIN_MSG_DRAW_MAX_Y	(WIN_MSG_DRAW_MIN_Y + WIN_MSG_DRAW_HEIGHT - 1)
+#define	WIN_MSG_DRAW_MAX_X	\
+		(WIN_MSG_DRAW_MIN_X + WIN_MSG_DRAW_WIDTH - 1)
+#define	WIN_MSG_DRAW_MAX_Y	\
+		(WIN_MSG_DRAW_MIN_Y + WIN_MSG_DRAW_HEIGHT - 1)
 
-#define	WIN_MORE_DRAW_MIN_X	(WIN_MSG_DRAW_MAX_X - WIN_MORE_DRAW_WIDTH + 1)
+#define	WIN_MORE_DRAW_MIN_X	\
+		(WIN_MSG_DRAW_MAX_X - WIN_MORE_DRAW_WIDTH + 1)
 #define	WIN_MORE_DRAW_MIN_Y	WIN_MSG_DRAW_MIN_Y
 #define	WIN_MORE_DRAW_WIDTH	(str_len_draw( MSG_MORE ))
 
