@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fx.h,v 1.52 2007/01/11 17:31:34 bowkenken Exp $
+* $Id: fx.h,v 1.54 2008/02/14 08:44:16 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	FX_H
@@ -101,6 +101,8 @@ typedef enum {
 	FX_KIND_COUNTER_MAGIC,
 	FX_KIND_SUBSTITUTE,
 	FX_KIND_BURNING_HANDS,
+	FX_KIND_RALLY,
+	FX_KIND_IRON_MAN,
 	FX_KIND_MIND_READING,
 	FX_KIND_SPEED_UP,
 	FX_KIND_SPEED_DOWN,
