@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile-tab.h,v 1.18 2007/05/11 00:42:16 bowkenken Exp $
+* $Id: gfile-tab.h,v 1.20 2008/02/14 08:44:16 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GFILE_TAB_H
@@ -752,6 +752,8 @@ scroll_kind_t	g_scroll_trans_tab[] = {
 	SCROLL_KIND_MIND_READING,
 /* ɲ */
 	SCROLL_KIND_IDENTIFY_ALL_ITEM,
+	SCROLL_KIND_RALLY,
+	SCROLL_KIND_IRON_MAN,
 };
 
 /***************************************************************
@@ -1407,9 +1409,9 @@ spell_kind_t	g_spell_trans_tab[] = {
 
 	SPELL_KIND_SUBSTITUTE,	/* - */
 	SPELL_KIND_BURNING_HANDS,	/* - */
-	SPELL_KIND_DUMMY_NIN_1,	/* - */
-	SPELL_KIND_DUMMY_NIN_2,	/* - */
-	SPELL_KIND_MIND_READING,	/* - */
+	SPELL_KIND_RALLY,	/* -ڽ */
+	SPELL_KIND_IRON_MAN,	/* -Ŵ */
+	SPELL_KIND_MIND_READING,	/* -߿ */
 	SPELL_KIND_NIN_MAX_N,
 /* ANC */
 	SPELL_KIND_ANC_MIN_N,
@@ -1686,6 +1688,9 @@ fx_kind_t	g_fx_trans_tab[] = {
 	FX_KIND_STORE_LIGHT,
 	FX_KIND_COUNTER_MAGIC,
 	FX_KIND_POLYMORPH,
+/* ɲ */
+	FX_KIND_RALLY,
+	FX_KIND_IRON_MAN,
 };
 
 /***************************************************************
