@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: imenu.c,v 1.37 2007/12/15 08:18:28 bowkenken Exp $
+* $Id: imenu.c,v 1.40 2008/04/03 08:17:01 bowkenken Exp $
 ***************************************************************/
 
 #define	IMENU_C
@@ -532,6 +532,9 @@ void	show_map_hint_obj( long x, long y )
 		msg2 = get_item_mnr_name( item->mjr, item->mnr );
 	} else if( trap != NULL ){
 		msg1 = MSG_MAP_HINT_TRAP;
+		if( trap->flg_chked )
+			if( trap->tab != NULL )
+				msg2 = trap->tab->name;
 	} else if( door != NULL ){
 		if( chk_flg( door->flg, FLG_DOOR_SHOP ) ){
 			msg1 = MSG_MAP_HINT_SHOP;
@@ -547,7 +550,7 @@ void	show_map_hint_obj( long x, long y )
 
 	if( msg2 == NULL ){
 		print_msg( FLG_NULL, MSG_MAP_HINT_FMT_OBJ,
-				x, y, mjr, mnr, msg1, msg2 );
+				x, y, mjr, mnr, msg1 );
 	} else {
 		print_msg( FLG_NULL, MSG_MAP_HINT_FMT_OBJ_SUB,
 				x, y, mjr, mnr, msg1, msg2 );
@@ -3007,6 +3010,52 @@ char	*cb_menu_mul_msg_line( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_screen_size_init( menu_t **pp, menu_t **dflt )
+{
+	if( chk_flg_screen_size_auto() )
+		set_chk_on_menu( *pp, "auto" );
+	else
+		set_chk_off_menu( *pp, "auto" );
+
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_screen_size_auto( menu_t **pp, menu_t **dflt )
+{
+	if( chk_flg( (*pp)->flg, FLG_MENU_CHK_ON ) )
+		set_flg_screen_size_auto( TRUE );
+	else if( chk_flg( (*pp)->flg, FLG_MENU_CHK_OFF ) )
+		set_flg_screen_size_auto( FALSE );
+	else
+		return STR_MENU_ERR;
+
+	return STR_MENU_CANCEL;
+}
+
+/**/
+
+char	*cb_menu_screen_size_lines( menu_t **pp, menu_t **dflt )
+{
+	long	n;
+	char	*ret;
+
+	n = get_screen_size_lines();
+
+	ret = exec_menu_sel_num( &n,
+			SCREEN_SIZE_MIN_LINES,
+			SCREEN_SIZE_MAX_LINES );
+	if( ret == NULL ){
+		set_screen_size_lines( n );
+		return STR_MENU_CANCEL;
+	}
+
+	return ret;
+}
+
+/**/
+
 char	*cb_menu_vfx( menu_t **pp, menu_t **dflt )
 {
 	menu_t	*p;
