@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: inc.h,v 1.43 2007/06/07 22:58:14 bowkenken Exp $
+* $Id: inc.h,v 1.70 2008/01/11 09:12:57 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	INC_H
@@ -39,6 +39,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -62,6 +63,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
@@ -94,6 +96,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 #include	"town.h"
@@ -117,6 +120,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -151,6 +155,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -174,6 +179,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -201,16 +207,14 @@
 #include	"call-prot.h"
 
 # ifdef	D_DOS
-#  include	<windows.h>
-#  include	<conio.h>
-#  ifndef	D_WS
-#   ifdef	D_WIN
-#    include	"../lnl-dos/stdafx.h"
-#   else
-#    include	"lnl-dos/stdafx.h"
-#   endif
+#  ifndef	_WINDOWS_
+#   include	<windows.h>
 #  endif
-# endif
+#  include	<conio.h>
+#  ifndef D_DOWS
+#   include	"lnl-dos/stdafx.h"
+#  endif
+# endif /* D_DOS */
 
 #endif	/* CURS_C */
 
@@ -220,6 +224,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 #include	"turn.h"
 /*#include	"dun.h"*/
 #include	"town.h"
@@ -243,6 +248,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -275,6 +281,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 #include	"town.h"
@@ -298,6 +305,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
@@ -342,6 +350,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 #include	"dun.h"
 #include	"town.h"
@@ -365,6 +374,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -402,6 +412,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -425,6 +436,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
@@ -457,6 +469,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 #include	"turn.h"
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -480,6 +493,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
@@ -512,6 +526,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 #include	"turn.h"
 #include	"dun.h"
 #include	"town.h"
@@ -535,6 +550,7 @@
 #include	"ver.h"
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -559,6 +575,12 @@
 #include	"gfile-prot.h"
 #include	"msg-prot.h"
 
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+# include	"GraphConfToken.h"
+#endif
+
+#include	"call-prot.h"
+
 #endif	/* GFILE_C */
 
 /***************************************************************/
@@ -567,6 +589,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+#include	"scene.h"
 #include	"turn.h"
 #include	"town.h"
 #include	"item.h"
@@ -589,6 +612,7 @@
 #include	"ver.h"
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+#include	"scene-prot.h"
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -627,6 +651,18 @@
 
 #include	"main-prot.h"
 
+#ifdef	D_GTK
+# include	"main-x-prot.h"
+#endif	/* D_GTK */
+
+#ifdef	D_WS
+# include	"main-x-prot.h"
+#endif	/* D_WS */
+
+#ifdef	D_MFC
+# include	"main-dows-prot.h"
+#endif	/* D_MFC */
+
 #include	"call-prot.h"
 
 #endif	/* GMAIN_C */
@@ -637,6 +673,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 #include	"turn.h"
 #include	"dun.h"
 #include	"town.h"
@@ -660,6 +697,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -694,6 +732,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -717,6 +756,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
@@ -749,8 +789,8 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
-/*#include	"misc.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
 /*#include	"item.h"*/
@@ -773,6 +813,7 @@
 #include	"ver.h"
 #include	"gmain-prot.h"
 /*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -807,8 +848,8 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
-/*#include	"misc.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
 /*#include	"item.h"*/
@@ -831,6 +872,7 @@
 #include	"ver.h"
 #include	"gmain-prot.h"
 /*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -866,6 +908,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -889,6 +932,7 @@
 /*#include	"ver.h"*/
 /*#include	"gmain-prot.h"*/
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -913,6 +957,9 @@
 /*#include	"gfile-prot.h"*/
 /*#include	"msg-prot.h"*/
 
+#include	"nest-flg.h"
+#include	"nest-flg-prot.h"
+
 #include	"call-prot.h"
 
 #endif	/* MENU_C */
@@ -923,6 +970,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -946,6 +994,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -978,6 +1027,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 #include	"turn.h"
 /*#include	"dun.h"*/
 #include	"town.h"
@@ -1001,6 +1051,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -1035,6 +1086,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 #include	"turn.h"
 #include	"dun.h"
 #include	"town.h"
@@ -1058,6 +1110,7 @@
 /*#include	"ver.h"*/
 /*#include	"gmain-prot.h"*/
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -1091,6 +1144,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -1114,6 +1168,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
@@ -1146,6 +1201,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -1169,6 +1225,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 /*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -1201,6 +1258,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 #include	"town.h"
@@ -1224,6 +1282,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -1256,6 +1315,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 #include	"dun.h"
 /*#include	"town.h"*/
@@ -1279,6 +1339,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
@@ -1312,6 +1373,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 #include	"turn.h"
 #include	"dun.h"
 /*#include	"town.h"*/
@@ -1335,6 +1397,7 @@
 /*#include	"ver.h"*/
 /*#include	"gmain-prot.h"*/
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
@@ -1367,6 +1430,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -1390,6 +1454,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
@@ -1422,6 +1487,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 #include	"turn.h"
 /*#include	"dun.h"*/
 #include	"town.h"
@@ -1445,6 +1511,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -1477,6 +1544,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 #include	"turn.h"
 /*#include	"dun.h"*/
 #include	"town.h"
@@ -1500,6 +1568,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -1532,6 +1601,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 #include	"dun.h"
 /*#include	"town.h"*/
@@ -1555,6 +1625,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
@@ -1587,6 +1658,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 #include	"turn.h"
 /*#include	"dun.h"*/
 #include	"town.h"
@@ -1610,6 +1682,7 @@
 /*#include	"ver.h"*/
 /*#include	"gmain-prot.h"*/
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 /*#include	"dun-prot.h"*/
 #include	"town-prot.h"
@@ -1636,6 +1709,63 @@
 
 #endif	/* TURN_C */
 
+/***************************************************************/
+
+#ifdef	SCENE_C
+
+#include	"gmain.h"
+/*#include	"misc.h"*/
+#include	"scene.h"
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+/*#include	"replay.h"*/
+/*#include	"draw.h"*/
+/*#include	"curs.h"*/
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+/*#include	"msg.h"*/
+/*#include	"ver.h"*/
+/*#include	"gmain-prot.h"*/
+/*#include	"misc-prot.h"*/
+#include	"scene-prot.h"
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+/*#include	"draw-prot.h"*/
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
+
+#endif	/* SCENE_C */
+
 /***************************************************************
 * xlnl
 ***************************************************************/
@@ -1644,6 +1774,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -1667,6 +1798,7 @@
 #include	"ver.h"
 #include	"gmain-prot.h"
 /*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -1694,72 +1826,17 @@
 #include	"main-x-prot.h"
 #include	"call-prot.h"
 
+#include	<gtk/gtk.h>
+
 #endif	/* MAIN_X_C */
 
 /***************************************************************/
 
-#ifdef	MAIN_WIN_C
-
-#include	"gmain.h"
-/*#include	"misc.h"*/
-/*#include	"turn.h"*/
-/*#include	"dun.h"*/
-/*#include	"town.h"*/
-/*#include	"item.h"*/
-/*#include	"spell.h"*/
-/*#include	"chr.h"*/
-/*#include	"party.h"*/
-/*#include	"mnstr.h"*/
-/*#include	"pet.h"*/
-/*#include	"fight.h"*/
-/*#include	"fx.h"*/
-/*#include	"trap.h"*/
-/*#include	"replay.h"*/
-#include	"draw.h"
-/*#include	"curs.h"*/
-/*#include	"menu.h"*/
-/*#include	"amenu.h"*/
-/*#include	"request.h"*/
-/*#include	"gfile.h"*/
-#include	"msg.h"
-#include	"ver.h"
-#include	"gmain-prot.h"
-/*#include	"misc-prot.h"*/
-/*#include	"turn-prot.h"*/
-/*#include	"dun-prot.h"*/
-/*#include	"town-prot.h"*/
-/*#include	"item-prot.h"*/
-/*#include	"spell-prot.h"*/
-/*#include	"chr-prot.h"*/
-/*#include	"party-prot.h"*/
-/*#include	"mnstr-prot.h"*/
-/*#include	"pet-prot.h"*/
-/*#include	"fight-prot.h"*/
-/*#include	"fx-prot.h"*/
-/*#include	"trap-prot.h"*/
-/*#include	"replay-prot.h"*/
-#include	"draw-prot.h"
-/*#include	"curs-prot.h"*/
-/*#include	"menu-prot.h"*/
-/*#include	"mmenu-prot.h"*/
-/*#include	"imenu-prot.h"*/
-/*#include	"tmenu-prot.h"*/
-/*#include	"amenu-prot.h"*/
-/*#include	"request-prot.h"*/
-/*#include	"gfile-prot.h"*/
-/*#include	"msg-prot.h"*/
-
-#include	"main-win-prot.h"
-#include	"call-prot.h"
-
-#endif	/* MAIN_WIN_C */
-
-/***************************************************************/
-
-#ifdef	MAIN_GTK_CPP
+#ifdef	MAIN_DOWS_CPP
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
+#include	"scene.h"
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -1779,10 +1856,11 @@
 /*#include	"amenu.h"*/
 /*#include	"request.h"*/
 /*#include	"gfile.h"*/
-/*#include	"msg.h"*/
-/*#include	"ver.h"*/
+#include	"msg.h"
+#include	"ver.h"
 #include	"gmain-prot.h"
 /*#include	"misc-prot.h"*/
+#include	"scene-prot.h"
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -1796,7 +1874,74 @@
 /*#include	"fx-prot.h"*/
 /*#include	"trap-prot.h"*/
 /*#include	"replay-prot.h"*/
-#include	"draw-prot.h"
+/*#include	"draw-prot.h"*/
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+#include	"imenu-prot.h"
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
+
+#include	"MouseMap.h"
+#include	"GlobalVar.h"
+
+#include	"main-dows-prot.h"
+#include	"call-prot.h"
+
+#include	"xlnl-dows/stdafx.h"
+#include	"xlnl-dows/xlnl-dows.h"
+#include	"xlnl-dows/MainFrm.h"
+
+#endif	/* MAIN_DOWS_CPP */
+
+/***************************************************************/
+
+#ifdef	MAIN_GTK_CPP
+
+#include	"gmain.h"
+/*#include	"misc.h"*/
+#include	"scene.h"
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+#include	"chr.h"
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+/*#include	"replay.h"*/
+#include	"draw.h"
+/*#include	"curs.h"*/
+#include	"menu.h"
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+/*#include	"msg.h"*/
+/*#include	"ver.h"*/
+#include	"gmain-prot.h"
+/*#include	"misc-prot.h"*/
+#include	"scene-prot.h"
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+/*#include	"draw-prot.h"*/
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
 /*#include	"mmenu-prot.h"*/
@@ -1810,14 +1955,14 @@
 #include	<gtk/gtk.h>
 #include	<gdk-pixbuf/gdk-pixbuf.h>
 
+#include	"MouseMap.h"
+#include	"GraphConf.h"
+#include	"GlobalVar.h"
+
 #include	"main-x-prot.h"
 #include	"main-gtk-prot.h"
 #include	"call-prot.h"
 
-#include	"MouseMap.h"
-
-#include	"GlobalVar.h"
-
 #endif	/* MAIN_GTK_CPP */
 
 /***************************************************************/
@@ -1834,11 +1979,11 @@
 #  include "GameThread.h"
 #  include "GuiMenu.h"
 #  include "PcgDun.h"
+#  include "GraphConfToken.h"
 #  include "GlobalVar.h"
 #  include "gmain-prot.h"
 #  include "chr-prot.h"
 #  include "draw-prot.h"
-#  include "call-prot.h"
 # elif	defined( D_GTK )
 #  include "gmain.h"
 #  include "misc.h"
@@ -1847,28 +1992,133 @@
 #  include "GameThread.h"
 #  include "GuiMenu.h"
 #  include "PcgDun.h"
+#  include "GraphConfToken.h"
+#  include "GlobalVar.h"
+#  include "gmain-prot.h"
+#  include "chr-prot.h"
+#  include "draw-prot.h"
+# elif	defined( D_MFC )
+#  include "gmain.h"
+#  include "misc.h"
+#  include "chr.h"
+#  include "draw.h"
+#  include "GameThread.h"
+#  include "GuiMenu.h"
+#  include "PcgDun.h"
+#  include "GraphConfToken.h"
 #  include "GlobalVar.h"
 #  include "gmain-prot.h"
 #  include "chr-prot.h"
 #  include "draw-prot.h"
-#  include "call-prot.h"
 # else
 #  include "gmain.h"
 #  include "misc.h"
 #  include "chr.h"
 #  include "draw.h"
 #  include "chr-prot.h"
-#  include "call-prot.h"
 # endif
 
+# include "call-prot.h"
+
 #endif	/* CALL_CPP */
 
 /***************************************************************/
 
+#ifdef	SEL_CONF_CPP
+
+#include	"gmain.h"
+/*#include	"misc.h"*/
+/*#include	"scene.h"*/
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+#include	"town.h"
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+/*#include	"replay.h"*/
+#include	"draw.h"
+/*#include	"curs.h"*/
+#include	"menu.h"
+#include	"amenu.h"
+/*#include	"request.h"*/
+#include	"gfile.h"
+/*#include	"msg.h"*/
+/*#include	"ver.h"*/
+/*#include	"gmain-prot.h"*/
+/*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+/*#include	"draw-prot.h"*/
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+#include	"gfile-prot.h"
+/*#include	"msg-prot.h"*/
+
+#include	"GraphConf.h"
+
+#ifdef D_WS
+# include <WSCwindow.h>
+# include <WSCbase.h>
+# include <WSCvbtn.h>
+# include <WSDmouse.h>
+#endif /* D_WS */
+
+#ifdef D_GTK
+# include <gtk/gtk.h>
+# include <gdk/gdk.h>
+# include "main-gtk-prot.h"
+#endif /* D_GTK */
+
+#include "SelConf.h"
+#include "GlobalVar.h"
+
+#ifdef D_MFC
+# include "xlnl-dows/stdafx.h"
+# include "xlnl-dows/SelConfDlg.h"
+# include "main-dows-prot.h"
+#endif /* D_MFC */
+
+#endif	/* SEL_CONF_CPP */
+
+/***************************************************************/
+
+#ifdef	GRAPH_CONF_CPP
+
+#include	"GraphConf.h"
+#include	"GlobalVar.h"
+
+#endif	/* GRAPH_CONF_CPP */
+
+/***************************************************************/
+
 #ifdef	GUI_MESSAGE_CPP
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -1892,6 +2142,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 /*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -1917,21 +2168,96 @@
 /*#include	"msg-prot.h"*/
 
 #ifdef D_WS
-#endif // D_WS
+#endif /* D_WS */
 
 #ifdef D_GTK
 # include <gtk/gtk.h>
 # include "GuiMisc.h"
-#endif // D_GTK
+#endif /* D_GTK */
+
+#ifdef D_MFC
+# include "xlnl-dows/stdafx.h"
+# include "GuiMisc.h"
+#endif /* D_MFC */
 
 #endif	/* GUI_MESSAGE_CPP */
 
 /***************************************************************/
 
+#ifdef	GUI_STAT_CPP
+
+#include	"gmain.h"
+#include	"misc.h"
+/*#include	"scene.h"*/
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+#include	"party.h"
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+#include	"draw.h"
+/*#include	"curs.h"*/
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+#include	"msg.h"
+/*#include	"ver.h"*/
+#include	"gmain-prot.h"
+#include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+#include	"party-prot.h"
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+#include	"draw-prot.h"
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
+
+#ifdef D_GTK
+# include <gtk/gtk.h>
+# include <gdk/gdk.h>
+#endif /* D_GTK */
+
+#ifdef D_MFC
+# include "xlnl-dows/StatWnd.h"
+#endif /* D_MFC */
+
+#include "GuiStat.h"
+#include "GlobalVar.h"
+
+#ifdef D_GTK
+#include "main-gtk-prot.h"
+#endif /* D_GTK */
+
+#endif	/* GUI_STAT_CPP */
+
+/***************************************************************/
+
 #ifdef	GUI_NUM_CPP
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -1955,6 +2281,7 @@
 /*#include	"ver.h"*/
 /*#include	"gmain-prot.h"*/
 #include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -1980,12 +2307,12 @@
 /*#include	"msg-prot.h"*/
 
 #ifdef D_WS
-#endif // D_WS
+#endif /* D_WS */
 
 #ifdef D_GTK
 # include <gtk/gtk.h>
 # include "GuiMisc.h"
-#endif // D_GTK
+#endif /* D_GTK */
 
 #endif	/* GUI_NUM_CPP */
 
@@ -1995,6 +2322,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
+/*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -2018,6 +2346,7 @@
 /*#include	"ver.h"*/
 /*#include	"gmain-prot.h"*/
 /*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
 /*#include	"town-prot.h"*/
@@ -2043,32 +2372,37 @@
 /*#include	"msg-prot.h"*/
 
 #ifdef D_WS
-//@@@
-//# include <WScom.h>
-//# include <WSDappDev.h>
-//# include <WSCmainWindow.h>
-//# include <WSCfunctionList.h>
-//# include <WSCbase.h>
-//# include <WSCwindow.h>
 # include <WSCvifield.h>
-#endif // D_WS
+# include "MapWin.h"
+#endif /* D_WS */
 
 #ifdef D_GTK
 # include <gtk/gtk.h>
 # include "GuiMisc.h"
-#endif // D_GTK
+#endif /* D_GTK */
+
+#include "GuiInputString.h"
+#include "GlobalVar.h"
+
+#ifdef D_MFC
+# include "xlnl-dows/InputLineDlg.h"
+#endif // D_MFC
 
 #endif	/* GUI_INPUT_STRING_CPP */
 
 /***************************************************************/
 
-#if	defined( D_WIN )
-# include	"main-win-prot.h"
+#if 0
+#if	defined( D_WS )
+# include	"main-ws-prot.h"
+#elif	defined( D_DOWS )
+# include	"main-dows-prot.h"
 #elif	defined( D_DOS )
 # include	"main-dos-prot.h"
 #else
 # include	"main-unix-prot.h"
 #endif
+#endif
 
 /***************************************************************/
 
