@@ -5,6 +5,7 @@ extern "C" {
 #endif
 
 void	init_item( void );
+void	close_item( void );
 void	init_wpn( void );
 void	init_armor( void );
 void	init_potion( void );
@@ -74,8 +75,9 @@ void	init_pipe( void );
 void	init_rare_goods( void );
 void	init_bone( void );
 void	init_coin( void );
+void	init_item_town( void );
 void	reset_item_town( void );
-void	clr_dun_item( void );
+void	garbage_collection_all_item( void );
 void	set_flg_item_garbage( item_t *item, bool_t flg );
 item_kind_t	make_item( long x, long y, long dun_lev );
 item_t	*make_item_sub( long dun_lev, bool_t flg_chest );
@@ -140,26 +142,26 @@ item_t	*make_item_sel(
 );
 void	set_item_face( item_t *item );
 void	set_item_name( item_t *item );
-void	set_item_name_wpn( item_t *item );
-void	set_item_name_armor( item_t *item );
-void	set_item_name_potion( item_t *item );
-void	set_item_name_scroll( item_t *item );
-void	set_item_name_stick( item_t *item );
-void	set_item_name_acce( item_t *item );
-void	set_item_name_inst( item_t *item );
-void	set_item_name_anthology( item_t *item );
-void	set_item_name_light( item_t *item );
-void	set_item_name_spike( item_t *item );
-void	set_item_name_food( item_t *item );
-void	set_item_name_chest( item_t *item );
-void	set_item_name_tobacco( item_t *item );
-void	set_item_name_pipe( item_t *item );
-void	set_item_name_disposal( item_t *item );
-void	set_item_name_rare_goods( item_t *item );
-void	set_item_name_bone( item_t *item );
-void	set_item_name_coin( item_t *item );
-void	set_item_name_junk( item_t *item );
-void	clean_all_disposal( mbr_t *mbr );
+bool_t	set_item_name_wpn( item_t *item );
+bool_t	set_item_name_armor( item_t *item );
+bool_t	set_item_name_potion( item_t *item );
+bool_t	set_item_name_scroll( item_t *item );
+bool_t	set_item_name_stick( item_t *item );
+bool_t	set_item_name_acce( item_t *item );
+bool_t	set_item_name_inst( item_t *item );
+bool_t	set_item_name_anthology( item_t *item );
+bool_t	set_item_name_light( item_t *item );
+bool_t	set_item_name_spike( item_t *item );
+bool_t	set_item_name_food( item_t *item );
+bool_t	set_item_name_chest( item_t *item );
+bool_t	set_item_name_tobacco( item_t *item );
+bool_t	set_item_name_pipe( item_t *item );
+bool_t	set_item_name_disposal( item_t *item );
+bool_t	set_item_name_rare_goods( item_t *item );
+bool_t	set_item_name_bone( item_t *item );
+bool_t	set_item_name_coin( item_t *item );
+bool_t	set_item_name_junk( item_t *item );
+bool_t	clean_all_disposal( mbr_t *mbr );
 bool_t	identify_item( item_t *item );
 bool_t	identify_potion( item_t *item );
 bool_t	identify_scroll( item_t *item );
@@ -271,6 +273,7 @@ void	dec_chest_ref( item_t *chest );
 void	remove_mbr_del_item( long ls_mbr_n );
 void	move_ls_item( item_t *dst, item_t *src );
 item_t	*alloc_item( void );
+void	free_item_ls( item_t *ls );
 void	free_item( item_t *p );
 void	ins_ls_item( item_t *ls, item_t *p );
 bool_t	ins_sort_item( item_t *ls, item_t *item );
@@ -297,13 +300,6 @@ item_t	*get_shop_tobacco_item_asgn( void );
 rate_t	get_resi_armor( mbr_t *p, resi_kind_t resi );
 bool_t	chk_wear_armor( mbr_t *mbr );
 spell_kind_t	get_inst_spell_kind( mbr_t *mbr );
-rate_t	add_hit( long n );
-rate_t	add_wpn_crtcl( long n );
-rate_t	add_dam( long n );
-rate_t	add_dam_two_handed_wpn( mbr_t *mbr, item_t *wpn );
-rate_t	add_def( long n );
-rate_t	add_armor_crtcl( long n );
-rate_t	add_ac( long n );
 long	expr_wpn_add_hit( long lev );
 long	expr_wpn_add_crtcl( long lev );
 long	expr_wpn_add_dam( long lev );
