@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-dos.c,v 1.13 2007/03/02 05:19:47 bowkenken Exp $
+* $Id: main-dos.c,v 1.16 2008/04/03 14:02:52 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -52,3 +52,13 @@ int	main_dos( int argc, char **argv )
 
 	return EXIT_FAILURE;
 }
+
+/***************************************************************
+* λ
+* long code : λ
+***************************************************************/
+
+void	gexit( long code )
+{
+	exit( code );
+}
