@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.188 2007/06/11 08:25:36 bowkenken Exp $
+* $Id: mnstr.c,v 1.190 2008/02/05 19:55:44 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -84,7 +84,7 @@ void	init_mnstr( void )
 	long	i, max_i;
 
 	max_i = sizeof( mnstr_tab ) / sizeof( mnstr_tab[0] );
-	for( i = 0; max_i; i++ ){
+	for( i = 0; i < max_i; i++ ){
 		if( mnstr_tab[i].mnstr_kind == MNSTR_KIND_NULL )
 			break;
 
@@ -93,7 +93,7 @@ void	init_mnstr( void )
 
 	min_lev = 0;
 	max_i = sizeof( mnstr_lev_tab ) / sizeof( mnstr_lev_tab[0] );
-	for( i = 0; max_i; i++ ){
+	for( i = 0; i < max_i; i++ ){
 		mnstr_lev_tab_t	*tab;
 
 		tab = &(mnstr_lev_tab[i]);
@@ -1661,7 +1661,7 @@ void	print_ls_mnstr( void )
 
 	min_lev = 0;
 	max_i = sizeof( mnstr_lev_tab ) / sizeof( mnstr_lev_tab[0] );
-	for( i = 0; max_i; i++ ){
+	for( i = 0; i < max_i; i++ ){
 		mnstr_tab_t	*tab;
 
 		if( mnstr_lev_tab[i].kind == MNSTR_KIND_NULL )
@@ -1842,12 +1842,22 @@ mnstr_tab_t	*get_mnstr_tab_rand_sub(
 )
 {
 	mnstr_kind_t	kind;
-	long	i, max_i, n;
+	long	loop_lev, lev_offset;
+	long	n;
+	long	i;
+
+	loop_lev = get_mnstr_lev_tab_max();
+	lev_offset = 0;
+	for( i = 0; i < LOOP_MAX_10000; i++ ){
+		if( (lev_offset + loop_lev) < labs( dun_lev ) )
+			lev_offset += loop_lev;
+		else
+			break;
+	}
 
 	kind = MNSTR_KIND_NULL;
 	n = 0;
-	max_i = sizeof( mnstr_lev_tab ) / sizeof( mnstr_lev_tab[0] );
-	for( i = 0; max_i; i++ ){
+	for( i = 0; i < LOOP_MAX_10000; i++ ){
 		mnstr_lev_tab_t	*lev_p;
 
 		lev_p = &(mnstr_lev_tab[i]);
@@ -1855,9 +1865,9 @@ mnstr_tab_t	*get_mnstr_tab_rand_sub(
 		if( lev_p->kind == MNSTR_KIND_NULL )
 			break;
 
-		if( labs( dun_lev ) < lev_p->min_lev )
+		if( (lev_p->min_lev + lev_offset) > labs( dun_lev ) )
 			continue;
-		if( labs( dun_lev ) > lev_p->max_lev )
+		if( (lev_p->max_lev + lev_offset) < labs( dun_lev ) )
 			if( !flg_no_chk_max )
 				continue;
 
@@ -1907,7 +1917,7 @@ mnstr_tab_t	*get_towner_tab_rand( void )
 	max_i = sizeof( towner_tab ) / sizeof( towner_tab[0] );
 
 	sum = 0;
-	for( i = 0; max_i; i++ ){
+	for( i = 0; i < max_i; i++ ){
 		if( towner_tab[i].kind == MNSTR_KIND_NULL )
 			break;
 
@@ -1917,7 +1927,7 @@ mnstr_tab_t	*get_towner_tab_rand( void )
 	n = randm( sum );
 
 	sum = 0;
-	for( i = 0; max_i; i++ ){
+	for( i = 0; i < max_i; i++ ){
 		if( towner_tab[i].kind == MNSTR_KIND_NULL )
 			break;
 
@@ -1932,6 +1942,27 @@ mnstr_tab_t	*get_towner_tab_rand( void )
 	return get_mnstr_tab( towner_tab[i].kind, 0 );
 }
 
+/***************************************************************
+* 󥹥νиơ֥Υ롼פޤǤκ糬򸡺
+* return : 糬
+***************************************************************/
+
+long	get_mnstr_lev_tab_max( void )
+{
+	long	max_lev;
+	long	i;
+
+	max_lev = 0;
+	for( i = 0; i < LOOP_MAX_10000; i++ ){
+		if( mnstr_lev_tab[i].kind == MNSTR_KIND_NULL )
+			break;
+
+		max_lev = mnstr_lev_tab[i].max_lev;
+	}
+
+	return max_lev;
+}
+
 /***************************************************************
 * 󥹥νиơ֥򸡺
 * mnstr_kind_t mnstr_kind : 󥹥μ
@@ -1947,7 +1978,7 @@ mnstr_lev_tab_t	*get_mnstr_lev_tab( mnstr_kind_t mnstr_kind, long dun_lev )
 	tab = NULL;
 	n = 0;
 	max_i = sizeof( mnstr_lev_tab ) / sizeof( mnstr_lev_tab[0] );
-	for( i = 0; max_i; i++ ){
+	for( i = 0; i < max_i; i++ ){
 		mnstr_lev_tab_t	*p;
 
 		p = &(mnstr_lev_tab[i]);
