@@ -14,6 +14,11 @@ bool_t	get_flg_lang_ls_priority( void );
 bool_t	set_flg_lang_ls_priority( bool_t flg );
 char	*get_lang_kind_name( lang_kind_t kind );
 lang_kind_t	trans_lang_id_to_kind( char *id );
+long	str_len_draw( const char *s );
+long	str_len_draw_english( const char *s );
+long	str_len_draw_japanese_euc( const char *s );
+long	str_len_draw_japanese_utf_8( const char *s );
+long	str_len_draw_japanese_sjis( const char *s );
 
 #ifdef __cplusplus
 }
