@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: msg.c,v 1.34 2007/11/08 13:13:37 bowkenken Exp $
+* $Id: msg.c,v 1.36 2008/02/04 04:27:52 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -39,7 +39,7 @@
 
 #define	STR_S	"%s"
 #define	STR_ENV_LANG	"LANG"
-#define	STR_SUPPORT_LANG	"Supporting language is:"
+#define	STR_SUPPORT_LANG	"Supporting languages are:"
 #define	STR_SUPPORT_LANG_LIST	"\t`%s'\n"
 #define	STR_ERR_LANG	"Don't support language: LANG=%s"
 #define	STR_ERR_REDEFINED_MSG	"Redefined message data: LANG=%s %ld `%s'"
@@ -196,7 +196,7 @@ void	init_msg( void )
 	}
 	g_lang_kind_next = g_lang_kind;
 
-	/* ꤵ줿줬Ĥʤä饨顼λ */
+	/* ꤵ줿줬Ĥʤä饨顼 */
 
 	if( g_lang_kind >= LANG_KIND_MAX_N ){
 		print_err( STR_ERR_LANG, lang );
@@ -209,7 +209,10 @@ void	init_msg( void )
 					lang_tab[k].id_n );
 		}
 		fprintf( stderr, "\n" );
-		exit_game( EXIT_FAILURE );
+		/* exit_game( EXIT_FAILURE ); */
+
+		g_lang_kind = LANG_KIND_ENGLISH;
+		g_lang_kind_next = g_lang_kind;
 	}
 
 	for( m = 0; m < N_MSG_MAX_N; m++ )
