@@ -20,6 +20,9 @@ void	new_mbr(
 bool_t	reset_mbr_resi( mbr_t *mbr );
 void	set_mbr_dir( void );
 void	appear_party( void );
+bool_t	appear_party_randm( void );
+bool_t	appear_party_srch( void );
+void	appear_party_force( void );
 long	get_party_dun_max_lev( void );
 void	scroll_center_appear_party( void );
 void	clr_map_all_mbr( void );
