@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.198 2007/11/06 03:17:59 bowkenken Exp $
+* $Id: party.c,v 1.200 2008/03/25 22:27:41 bowkenken Exp $
 ***************************************************************/
 
 #define	PARTY_C
@@ -1395,8 +1395,8 @@ void	set_mbr_dir( void )
 
 void	appear_party( void )
 {
-	bool_t	flg_force = TRUE;
-	long	i, n;
+	bool_t	flg_force;
+	long	n;
 
 	for( n = 0; n < MBR_MAX_N; n++ ){
 		lost_trgt( party.mbr[n] );
@@ -1404,9 +1404,36 @@ void	appear_party( void )
 	}
 
 	release_all_mbr();
-
 	clr_map_all_mbr();
 
+	flg_force = FALSE;
+	do {
+		if( appear_party_randm() )
+			break;
+		if( appear_party_srch() )
+			break;
+		appear_party_force();
+		flg_force = TRUE;
+	} while( 0 );
+
+	if( !flg_force )
+		set_map_all_mbr();
+
+	appear_all_pet();
+
+	next_pos_square( 0 );
+	scroll_center_appear_party();
+	set_flg_find_all_mnstr();
+
+	redraw_all();
+}
+
+/**/
+
+bool_t	appear_party_randm( void )
+{
+	long	i, n;
+
 	for( i = 0; i < LOOP_MAX_1000; i++ ){
 		party.square.x = 1 + randm( MAP_MAX_X - 2);
 		party.square.y = 1 + randm( MAP_MAX_Y - 2);
@@ -1436,34 +1463,96 @@ void	appear_party( void )
 		}
 		if( n >= MBR_MAX_N ){
 			/* ư褿 */
-			flg_force = FALSE;
-			break;
+			return TRUE;
 		}
 	}
 
-	if( flg_force ){
-		for( n = 0; n < MBR_MAX_N; n++ ){
-			party.mbr[n]->x = MAP_DEL_X;
-			party.mbr[n]->y = MAP_DEL_Y;
-
-			put_chr( party.mbr[n],
-					MAP_MAX_X / 2,
-					MAP_MAX_Y / 2 );
-		}
-	} else {
-		set_map_all_mbr();
-	}
-
-	appear_all_pet();
-
-	next_pos_square( 0 );
-	scroll_center_appear_party();
-	set_flg_find_all_mnstr();
-
-	redraw_all();
+	/* ưʤä */
+	return FALSE;
 }
 
-/**/
+bool_t	appear_party_srch( void )
+{
+	long	randm_x, randm_y;
+	long	xx, yy;
+	long	x, y;
+	long	n;
+
+	randm_x = randm( MAP_MAX_X );
+	randm_y = randm( MAP_MAX_Y );
+
+	for( yy = 0; yy < MAP_MAX_Y; yy++ ){
+		for( xx = 0; xx < MAP_MAX_X; xx++ ){
+			x = (randm_x + xx) % MAP_MAX_X;
+			y = (randm_y + yy) % MAP_MAX_Y;
+			if( x < 1 )
+				continue;
+			if( y < 1 )
+				continue;
+			if( x >= MAP_MAX_X - 1 )
+				continue;
+			if( y >= MAP_MAX_Y - 1 )
+				continue;
+
+			party.square.x = x;
+			party.square.y = y;
+			party.square.pre_x = party.square.x;
+			party.square.pre_y = party.square.y;
+
+			for( n = 0; n < MBR_MAX_N; n++ ){
+				long	nx, ny;
+
+				if( chk_flg_or( party.mbr[n]->stat,
+						FLG_STAT_NOT_EXIST
+						| FLG_STAT_DEAD ) ){
+					continue;
+				}
+
+				nx = party.square.x;
+				ny = party.square.y;
+				nx += party.square.chr_pos[n].x;
+				ny += party.square.chr_pos[n].y;
+				party.mbr[n]->x = nx;
+				party.mbr[n]->y = ny;
+				party.mbr[n]->pre_x = nx;
+				party.mbr[n]->pre_y = ny;
+
+				if( !can_move_chr( party.mbr[n], nx, ny ) ){
+					/* ֤˰ưʤ */
+					break;
+				}
+			}
+			if( n >= MBR_MAX_N ){
+				/* ư褿 */
+				return TRUE;
+			}
+		}
+	}
+
+	/* ưʤä */
+	return FALSE;
+}
+
+void	appear_party_force( void )
+{
+	long	x, y;
+	long	n;
+
+	x = 1 + randm( MAP_MAX_X - 2);
+	y = 1 + randm( MAP_MAX_Y - 2);
+
+	party.square.x = x;
+	party.square.y = y;
+	party.square.pre_x = party.square.x;
+	party.square.pre_y = party.square.y;
+
+	for( n = 0; n < MBR_MAX_N; n++ ){
+		party.mbr[n]->x = MAP_DEL_X;
+		party.mbr[n]->y = MAP_DEL_Y;
+
+		put_chr( party.mbr[n], x, y );
+	}
+}
 
 /***************************************************************
 * Сߤꤿֿ
