@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell-tab.h,v 1.15 2007/06/01 01:08:53 bowkenken Exp $
+* $Id: spell-tab.h,v 1.17 2008/02/14 08:44:16 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	SPELL_TAB_H
@@ -2452,6 +2452,26 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/spell/NIN/rally",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_RALLY, "",
+		cb_menu_spell, (void *)SPELL_KIND_RALLY,
+		FLG_NULL,
+	},
+
+	{
+		"/spell/NIN/iron_man",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_IRON_MAN, "",
+		cb_menu_spell, (void *)SPELL_KIND_IRON_MAN,
+		FLG_NULL,
+	},
+
 	{
 		"/spell/NIN/mind_reading",
 		"<Branch>",
