@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.167 2007/11/09 11:46:50 bowkenken Exp $
+* $Id: spell.c,v 1.170 2008/02/14 08:44:16 bowkenken Exp $
 ***************************************************************/
 
 #define	SPELL_C
@@ -134,11 +134,9 @@ void	init_spell_debug( void )
 	long	m;
 	long	k;
 
-#if	0
 	m = LS_MBR_N_BLADE;
 	for( k = SPELL_KIND_NIN_MIN_N + 1; k < SPELL_KIND_NIN_MAX_N; k++ )
 		cast_tab[m][k].flg_cast = TRUE;
-#endif
 
 	m = LS_MBR_N_CECILE;
 	for( k = SPELL_KIND_PRI_MIN_N + 1; k < SPELL_KIND_PRI_MAX_N; k++ ){
@@ -168,11 +166,9 @@ void	init_spell_debug( void )
 		cast_tab[m][k].flg_cast = TRUE;
 	}
 
-#if	0
 	m = LS_MBR_N_BEAUT;
 	for( k = SPELL_KIND_SHA_MIN_N + 1; k < SPELL_KIND_SHA_MAX_N; k++ )
 		cast_tab[m][k].flg_cast = FALSE;
-#endif
 
 	m = LS_MBR_N_EYE;
 	for( k = SPELL_KIND_SUM_MIN_N + 1; k < SPELL_KIND_SUM_MAX_N; k++ )
@@ -2063,10 +2059,11 @@ void	chr_cast_spell_sub(
 	case SPELL_KIND_BURNING_HANDS:
 		fx_magic_wpn_armor( chr, FX_KIND_BURNING_HANDS );
 		break;
-	case SPELL_KIND_DUMMY_NIN_1:
-/*@@@*/
-	case SPELL_KIND_DUMMY_NIN_2:
-/*@@@*/
+	case SPELL_KIND_RALLY:
+		fx_magic_wpn_armor( chr, FX_KIND_RALLY );
+		break;
+	case SPELL_KIND_IRON_MAN:
+		fx_magic_wpn_armor( chr, FX_KIND_IRON_MAN );
 		break;
 	case SPELL_KIND_MIND_READING:
 		fx_magic_wpn_armor( chr, FX_KIND_MIND_READING );
@@ -2456,8 +2453,8 @@ bool_t	chk_cast_spell_trgt( spell_kind_t spell, trgt_kind_t trgt )
 	case SPELL_KIND_INUNDATION:
 	case SPELL_KIND_SUBSTITUTE:
 	case SPELL_KIND_BURNING_HANDS:
-	case SPELL_KIND_DUMMY_NIN_1:
-	case SPELL_KIND_DUMMY_NIN_2:
+	case SPELL_KIND_RALLY:
+	case SPELL_KIND_IRON_MAN:
 	case SPELL_KIND_MIND_READING:
 		break;
 	case SPELL_KIND_NIN_MAX_N:
@@ -2775,8 +2772,8 @@ bool_t	chk_chr_learned_spell_nin(
 	case SPELL_KIND_INUNDATION:
 	case SPELL_KIND_SUBSTITUTE:
 	case SPELL_KIND_BURNING_HANDS:
-	case SPELL_KIND_DUMMY_NIN_1:
-	case SPELL_KIND_DUMMY_NIN_2:
+	case SPELL_KIND_RALLY:
+	case SPELL_KIND_IRON_MAN:
 	case SPELL_KIND_MIND_READING:
 	case SPELL_KIND_NIN_MAX_N:
 		break;
@@ -2824,8 +2821,13 @@ bool_t	chk_chr_learned_spell_nin(
 		if( tab->kind == SCROLL_KIND_BURNING_HANDS )
 			flg_learn = TRUE;
 		break;
-	case SPELL_KIND_DUMMY_NIN_1:
-	case SPELL_KIND_DUMMY_NIN_2:
+	case SPELL_KIND_RALLY:
+		if( tab->kind == SCROLL_KIND_RALLY )
+			flg_learn = TRUE;
+		break;
+	case SPELL_KIND_IRON_MAN:
+		if( tab->kind == SCROLL_KIND_IRON_MAN )
+			flg_learn = TRUE;
 		break;
 	case SPELL_KIND_MIND_READING:
 		if( tab->kind == SCROLL_KIND_MIND_READING )
@@ -3208,8 +3210,8 @@ char	*get_spell_vfx_str( spell_kind_t spell_kind )
 	case SPELL_KIND_INUNDATION:
 	case SPELL_KIND_SUBSTITUTE:
 	case SPELL_KIND_BURNING_HANDS:
-	case SPELL_KIND_DUMMY_NIN_1:
-	case SPELL_KIND_DUMMY_NIN_2:
+	case SPELL_KIND_RALLY:
+	case SPELL_KIND_IRON_MAN:
 	case SPELL_KIND_MIND_READING:
 	case SPELL_KIND_NIN_MAX_N:
 		break;
