@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.115 2007/06/07 02:09:16 bowkenken Exp $
+* $Id: tmenu.c,v 1.118 2008/01/11 09:12:57 bowkenken Exp $
 ***************************************************************/
 
 #define	TMENU_C
@@ -943,6 +943,7 @@ char	*menu_town_mbr_data(
 	mbr_t	**mbr;
 	long	n;
 	long	page_n;
+	data_n_t	data_n;
 
 	if( flg_ls_mbr ){
 		n = g_sel_ls_mbr->ls_mbr_n;
@@ -956,6 +957,7 @@ char	*menu_town_mbr_data(
 		return STR_MENU_ERR;
 
 	page_n = 0;
+	data_n = DATA_N_NEXT_PAGE;
 
 	while( 1 ){
 		long	add;
@@ -965,7 +967,7 @@ char	*menu_town_mbr_data(
 		if( flg_ls_mbr )
 			not_join_mbr( n, prev_mbr_n );
 
-		add = menu_mbr_data( mbr[n], &page_n, edit_kind );
+		add = menu_mbr_data( mbr[n], &page_n, &data_n, edit_kind );
 
 		if( flg_ls_mbr )
 			join_mbr( n, prev_mbr_n );
@@ -2067,6 +2069,7 @@ bool_t	exec_menu_new_mbr( void )
 	mbr_t	**ls_mbr;
 	race_t	race;
 	long	page_n;
+	data_n_t	data_n;
 	ask_t	ask;
 	long	n;
 
@@ -2084,8 +2087,10 @@ bool_t	exec_menu_new_mbr( void )
 			'@', race, MALE, 0, n );
 
 	page_n = 0;
+	data_n = DATA_N_NEXT_PAGE;
+
 	while( 1 ){
-		menu_mbr_data( ls_mbr[n], &page_n,
+		menu_mbr_data( ls_mbr[n], &page_n, &data_n,
 				MBR_DATA_EDIT_KIND_NEW );
 
 		ask = exec_menu_ask(
@@ -2636,7 +2641,7 @@ char	*cb_menu_load_bar( menu_t **pp, menu_t **dflt )
 {
 	menu_load_bar();
 
-//@@@
+/*@@@*/
 	return NULL;
 	return "/";
 	return "/bar";
