@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: trap.c,v 1.62 2007/03/31 21:16:03 bowkenken Exp $
+* $Id: trap.c,v 1.67 2008/01/11 09:12:57 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -37,6 +37,14 @@
 
 /***************************************************************/
 
+/* 1 ˤ櫤Ĥ(ǥХå) */
+
+#if	0
+# ifndef	D_TEST_TRAP_KIND
+#  define	D_TEST_TRAP_KIND	TRAP_KIND_CHUTE
+# endif
+#endif
+
 /*  */
 
 #define	TRAP_DIFFICULTY_LEV_RATE	RATE_LEV_PER_DUN_LEV
@@ -339,6 +347,8 @@ bool_t	make_trap_alloc( long dun_lev, trap_t *trap, long tab_n )
 	trap->difficulty = difficulty;
 
 	trap->flg_chked = FALSE;
+	trap->cx = +-0;
+	trap->cy = +-0;
 	trap->tab = get_trap_tab( trap_tab[tab_n].kind );
 
 	return TRUE;
@@ -545,7 +555,7 @@ void	chk_trap( chr_t *chr, chr_t *thief )
 	if( trap == NULL )
 		return;
 
-	if( chr->kind == CHR_KIND_MBR ){
+	if( is_mbr( chr ) ){
 		find_trap( trap );
 	} else {
 		if( chk_flg( chr->flg_map, FLG_MAP_CHR_FIND ) )
@@ -602,7 +612,7 @@ void	caught_trap( trap_t *trap, chr_t *chr )
 	if( chk_flg_or( chr->stat, FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) )
 		return;
 
-	if( chr->kind == CHR_KIND_MBR ){
+	if( is_mbr( chr ) ){
 		find_trap( trap );
 	} else {
 		if( chk_flg( chr->flg_map, FLG_MAP_CHR_FIND ) )
@@ -662,7 +672,7 @@ void	caught_trap( trap_t *trap, chr_t *chr )
 				_100_PERCENT );
 		break;
 	case TRAP_KIND_TELEPORT_PARTY:
-		if( (chr->kind == CHR_KIND_MBR) || is_pet( chr ) )
+		if( (is_mbr( chr )) || is_pet( chr ) )
 			teleport_party();
 		break;
 	case TRAP_KIND_TELEPORT:
@@ -768,7 +778,7 @@ void	caught_trap_chute( chr_t *chr )
 		return;
 
 	flg_party = FALSE;
-	if( chr->kind == CHR_KIND_MBR )
+	if( is_mbr( chr ) )
 		flg_party = TRUE;
 	if( chr->kind == CHR_KIND_MNSTR )
 		if( is_pet( chr ) )
@@ -1005,9 +1015,13 @@ trap_t	*get_trap( long x, long y )
 {
 	trap_t	*p;
 
-	for( p = dun_trap_asgn.next; p != &dun_trap_asgn; p = p->next )
+	for( p = dun_trap_asgn.next; p != &dun_trap_asgn; p = p->next ){
+		if( p == NULL )
+			return NULL;
+
 		if( (p->x == x) && (p->y == y) )
 			return p;
+	}
 
 	return NULL;
 }
